Class: OpenCV::CvConvexityDefect
- Inherits:
-
Object
- Object
- OpenCV::CvConvexityDefect
- Defined in:
- ext/opencv/cvconvexitydefect.cpp,
ext/opencv/cvconvexitydefect.cpp
Overview
Convexity defect
Instance Method Summary collapse
-
#depth ⇒ Number
Returns distance between the farthest point and the convex hull.
-
#depth_point ⇒ CvPoint
Returns the farthest from the convex hull point within the defect.
-
#end ⇒ CvPoint
Returns the point of the contour where the defect ends.
-
#start ⇒ CvPoint
Returns the point of the contour where the defect begins.
Instance Method Details
#depth ⇒ Number
Returns distance between the farthest point and the convex hull
65 66 67 68 69 |
# File 'ext/opencv/cvconvexitydefect.cpp', line 65 VALUE rb_depth(VALUE self) { return rb_float_new(CVCONVEXITYDEFECT(self)->depth); } |
#depth_point ⇒ CvPoint
Returns the farthest from the convex hull point within the defect
54 55 56 57 58 |
# File 'ext/opencv/cvconvexitydefect.cpp', line 54 VALUE rb_depth_point(VALUE self) { return cCvPoint::new_object(*CVCONVEXITYDEFECT(self)->depth_point); } |
#end ⇒ CvPoint
Returns the point of the contour where the defect ends
43 44 45 46 47 |
# File 'ext/opencv/cvconvexitydefect.cpp', line 43 VALUE rb_end(VALUE self) { return cCvPoint::new_object(*CVCONVEXITYDEFECT(self)->end); } |
#start ⇒ CvPoint
Returns the point of the contour where the defect begins
32 33 34 35 36 |
# File 'ext/opencv/cvconvexitydefect.cpp', line 32 VALUE rb_start(VALUE self) { return cCvPoint::new_object(*CVCONVEXITYDEFECT(self)->start); } |